==> nim_fluttify-0.1.2.tar.gz: lib/src/facade/extensions.dart <==
// ignore_for_file: non_constant_identifier_names
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:foundation_fluttify/foundation_fluttify.dart';
import 'package:nim_fluttify/src/android/android.export.g.dart';
import 'package:nim_fluttify/src/ios/ios.export.g.dart';

import 'enums.dart';
import 'models.dart';

extension com_netease_nimlib_sdk_msg_MessageBuilder_X
    on com_netease_nimlib_sdk_msg_MessageBuilder {
  static Future<com_netease_nimlib_sdk_msg_model_IMMessage> createCustomMessage(
    String sessionId,
    SessionType sessionType,
    String attachmentString,
  ) async {
    // invoke native method
    final __result__ = await MethodChannel('com.fluttify/nim_fluttify')
        .invokeMethod(
            'com.netease.nimlib.sdk.msg.MessageBuilder::createCustomMessage', {
      "sessionId": sessionId,
      "sessionType": sessionType.androidModel().index,
      "attachmentString": attachmentString,
    });

    if (__result__ == null) {
      return null;
    } else {
      final __return__ =
          com_netease_nimlib_sdk_msg_model_IMMessage.subInstance()
            ..refId = __result__
            ..tag__ = 'nim_fluttify';
      if (__return__ is Ref) kNativeObjectPool.add(__return__);
      return __return__;
    }
  }
}

extension com_netease_nimlib_sdk_chatroom_ChatRoomMessageBuilder_X
    on com_netease_nimlib_sdk_chatroom_ChatRoomMessageBuilder {
  static Future<com_netease_nimlib_sdk_chatroom_model_ChatRoomMessage>
      createChatRoomCustomMessage(
    String sessionId,
    String attachmentString,
  ) async {
    // invoke native method
    final __result__ = await MethodChannel('com.fluttify/nim_fluttify')
        .invokeMethod(
            'com.netease.nimlib.sdk.chatroom.ChatRoomMessageBuilder::createChatRoomCustomMessage',
            {
          "sessionId": sessionId,
          "attachmentString": attachmentString,
        });

    if (__result__ == null) {
      return null;
    } else {
      final __return__ =
          com_netease_nimlib_sdk_chatroom_model_ChatRoomMessage.subInstance()
            ..refId = __result__
            ..tag__ = 'nim_fluttify';
      if (__return__ is Ref) kNativeObjectPool.add(__return__);
      return __return__;
    }
  }
}

extension com_netease_nimlib_sdk_msg_model_IMMessage_X
    on com_netease_nimlib_sdk_msg_model_IMMessage {
  Future<String> getCustomAttachment() async {
    // invoke native method
    final __result__ =
        await MethodChannel('com.fluttify/nim_fluttify').invokeMethod(
      'com.netease.nimlib.sdk.msg.model.IMMessage::getCustomAttachment',
      {"refId": refId},
    );

    return __result__;
  }

  Future<Message> toMessage() async {
    // 文字消息
    final messageType = await getMsgType();
    debugPrint('收到 $messageType 消息');
    switch (messageType) {
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.text:
        return TextMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.image:
        return ImageMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.audio:
        return AudioMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.video:
        return VideoMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.file:
        return FileMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.custom:
        return CustomMessage.android(this);
      default:
        return null;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.location:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.avchat:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.notification:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.tip:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.robot:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.custom:
//        return CustomMessage.android(this);
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.appCustom:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.qiyuCustom:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.undef:
//        // TODO: Handle this case.
//        break;
    }
  }
}

extension NIMMessageX on NIMMessage {
  Future<Message> toMessage() async {
    final messageType = await get_messageType();
    switch (messageType) {
      case NIMMessageType.NIMMessageTypeText:
        return TextMessage.ios(this);
      case NIMMessageType.NIMMessageTypeImage:
        return ImageMessage.ios(this);
      case NIMMessageType.NIMMessageTypeAudio:
        return AudioMessage.ios(this);
      case NIMMessageType.NIMMessageTypeVideo:
        return VideoMessage.ios(this);
      case NIMMessageType.NIMMessageTypeFile:
        return FileMessage.ios(this);
      case NIMMessageType.NIMMessageTypeCustom:
        return CustomMessage.ios(this);
      default:
        return null;
//    case NIMMessageType.NIMMessageTypeLocation:
//    // TODO: Handle this case.
//    break;
//    case NIMMessageType.NIMMessageTypeNotification:
//    // TODO: Handle this case.
//    break;
//    case NIMMessageType.NIMMessageTypeTip:
//    // TODO: Handle this case.
//    break;
//    case NIMMessageType.NIMMessageTypeRobot:
//    // TODO: Handle this case.
//    break;
    }
  }
}

extension com_netease_nimlib_sdk_msg_attachment_MsgAttachment_X
    on com_netease_nimlib_sdk_msg_attachment_MsgAttachment {
  Future<bool> isCustomAttachment() async {
    // invoke native method
    final __result__ =
        await MethodChannel('com.fluttify/nim_fluttify').invokeMethod(
      'com.netease.nimlib.sdk.msg.attachment.MsgAttachment::isCustomAttachment',
      {"refId": refId},
    );

    return __result__;
  }
}

extension NIMCustomObjectX on NIMCustomObject {
  Future<void> setAttachmentString(String attachmentString) async {
    return MethodChannel('com.fluttify/nim_fluttify').invokeMethod(
      'NIMCustomObject::setAttachmentString',
      {'attachmentString': attachmentString, 'refId': refId},
    );
  }

  Future<String> getAttachmentString() async {
    return MethodChannel('com.fluttify/nim_fluttify').invokeMethod(
      'NIMCustomObject::getAttachmentString',
      {'refId': refId},
    );
  }
}

extension SessionTypeX on SessionType {
  com_netease_nimlib_sdk_msg_constant_SessionTypeEnum androidModel() {
    com_netease_nimlib_sdk_msg_constant_SessionTypeEnum _type;
    switch (this) {
      case SessionType.p2p:
        _type = com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.P2P;
        break;
      case SessionType.team:
        _type = com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.Team;
        break;
      case SessionType.chatroom:
        _type = com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.ChatRoom;
        break;
    }
    return _type;
  }

  NIMSessionType iosModel() {
    NIMSessionType _type;
    switch (this) {
      case SessionType.p2p:
        _type = NIMSessionType.NIMSessionTypeP2P;
        break;
      case SessionType.team:
        _type = NIMSessionType.NIMSessionTypeTeam;
        break;
      case SessionType.chatroom:
        _type = NIMSessionType.NIMSessionTypeChatroom;
        break;
    }
    return _type;
  }
}

extension com_netease_nimlib_sdk_StatusCode_X
    on com_netease_nimlib_sdk_StatusCode {
  StatusType toStatusType() {
    switch (this) {
      case com_netease_nimlib_sdk_StatusCode.CONNECTING:
        debugPrint('网易云信: 服务器连接中');
        return StatusType.connecting;
      case com_netease_nimlib_sdk_StatusCode.LOGINING:
        debugPrint('网易云信: 登录中');
        return StatusType.logining;
      case com_netease_nimlib_sdk_StatusCode.LOGINED:
        debugPrint('网易云信: 已经登录');
        return StatusType.logged;
      case com_netease_nimlib_sdk_StatusCode.UNLOGIN:
        debugPrint('网易云信: 登录失败');
        return StatusType.login_failed;
      case com_netease_nimlib_sdk_StatusCode.SYNCING:
        debugPrint('网易云信: 数据同步中');
        return StatusType.syncing;
      case com_netease_nimlib_sdk_StatusCode.NET_BROKEN:
        debugPrint('网易云信: 连接断开');
        return StatusType.net_broken;
      default:
        debugPrint('网易云信: 未登录');
        return StatusType.not_logged;
    }
  }
}

extension NIMLoginStepX on NIMLoginStep {
  StatusType toStatusType() {
    switch (this) {
      case NIMLoginStep.NIMLoginStepLogining:
        debugPrint('网易云信: 聊天室登录中');
        return StatusType.logining;
      case NIMLoginStep.NIMLoginStepLoginOK:
        debugPrint('网易云信: 聊天室已登录');
        return StatusType.logged;
      case NIMLoginStep.NIMLoginStepLoginFailed:
        debugPrint('网易云信: 登录失败');
        return StatusType.login_failed;
      case NIMLoginStep.NIMLoginStepLoseConnection:
        debugPrint('网易云信: 连接断开');
        return StatusType.net_broken;
      default:
        debugPrint('网易云信: 未知状态');
        return StatusType.logining;
    }
  }
}

extension NIMChatroomConnectionStateX on NIMChatroomConnectionState {
  StatusType toStatusType() {
    switch (this) {
      case NIMChatroomConnectionState.NIMChatroomConnectionStateEntering:
        debugPrint('网易云信: 聊天室登录中');
        return StatusType.logining;
      case NIMChatroomConnectionState.NIMChatroomConnectionStateEnterOK:
        debugPrint('网易云信: 聊天室已登录');
        return StatusType.logged;
      case NIMChatroomConnectionState.NIMChatroomConnectionStateEnterFailed:
        debugPrint('网易云信: 聊天室进入失败');
        return StatusType.not_logged;
      case NIMChatroomConnectionState.NIMChatroomConnectionStateLoseConnection:
        debugPrint('网易云信: 连接断开');
        return StatusType.net_broken;
      default:
        debugPrint('网易云信: 未知状态');
        return StatusType.logining;
    }
  }
}

extension com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason_X
    on com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason {
  KickOutReason toKickOutReason() {
    switch (this) {
      case com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason
          .CHAT_ROOM_INVALID:
        return KickOutReason.invalid_room;
      case com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason
          .KICK_OUT_BY_MANAGER:
        return KickOutReason.by_manager;
      case com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason
          .KICK_OUT_BY_CONFLICT_LOGIN:
        return KickOutReason.conflict_login;
      case com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason
          .BE_BLACKLISTED:
        return KickOutReason.black_list;
      default:
        return KickOutReason.unknown;
    }
  }
}

extension NIMChatroomKickReasonX on NIMChatroomKickReason {
  KickOutReason toKickOutReason() {
    switch (this) {
      case NIMChatroomKickReason.NIMChatroomKickReasonInvalidRoom:
        return KickOutReason.invalid_room;
      case NIMChatroomKickReason.NIMChatroomKickReasonByManager:
        return KickOutReason.by_manager;
      case NIMChatroomKickReason.NIMChatroomKickReasonByConflictLogin:
        return KickOutReason.conflict_login;
      // TODO 枚举序号不是递增, 会出错, 如果枚举有值, 就必须使用值
      case NIMChatroomKickReason.NIMChatroomKickReasonBlacklist:
        return KickOutReason.black_list;
      default:
        return KickOutReason.unknown;
    }
  }
}

extension com_netease_nimlib_sdk_NIMSDK_X on com_netease_nimlib_sdk_NIMSDK {
  static Future<com_netease_nimlib_sdk_msg_SystemMessageObserver>
      getSystemMessageObserver() async {
    // invoke native method
    final __result__ = await MethodChannel('com.fluttify/nim_fluttify')
        .invokeMethod(
            'com.netease.nimlib.sdk.NIMSDK::getSystemMessageObserver');

    // handle native call

    // convert native result to dart side object
    if (__result__ == null) {
      return null;
    } else {
      final __return__ =
          com_netease_nimlib_sdk_msg_SystemMessageObserver.subInstance()
            ..refId = __result__
            ..tag__ = 'nim_fluttify';
      if (__result__ is Ref) kNativeObjectPool.add(__return__);
      return __return__;
    }
  }
}

==> nim_fluttify-0.1.4.tar.gz: lib/src/facade/extensions.dart <==
// ignore_for_file: non_constant_identifier_names
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:foundation_fluttify/foundation_fluttify.dart';
import 'package:nim_fluttify/src/android/android.export.g.dart';
import 'package:nim_fluttify/src/ios/ios.export.g.dart';

import 'enums.dart';
import 'models.dart';

extension com_netease_nimlib_sdk_msg_MessageBuilder_X
    on com_netease_nimlib_sdk_msg_MessageBuilder {
  static Future<com_netease_nimlib_sdk_msg_model_IMMessage> createCustomMessage(
    String sessionId,
    SessionType sessionType,
    String attachmentString,
  ) async {
    // invoke native method
    final __result__ = await MethodChannel('com.fluttify/nim_fluttify')
        .invokeMethod(
            'com.netease.nimlib.sdk.msg.MessageBuilder::createCustomMessage', {
      "sessionId": sessionId,
      "sessionType": sessionType.androidModel().index,
      "attachmentString": attachmentString,
    });

    if (__result__ == null) {
      return null;
    } else {
      final __return__ =
          com_netease_nimlib_sdk_msg_model_IMMessage.subInstance()
            ..refId = __result__
            ..tag__ = 'nim_fluttify';
      if (__return__ is Ref) kNativeObjectPool.add(__return__);
      return __return__;
    }
  }
}

extension com_netease_nimlib_sdk_chatroom_ChatRoomMessageBuilder_X
    on com_netease_nimlib_sdk_chatroom_ChatRoomMessageBuilder {
  static Future<com_netease_nimlib_sdk_chatroom_model_ChatRoomMessage>
      createChatRoomCustomMessage(
    String sessionId,
    String attachmentString,
  ) async {
    // invoke native method
    final __result__ = await MethodChannel('com.fluttify/nim_fluttify')
        .invokeMethod(
            'com.netease.nimlib.sdk.chatroom.ChatRoomMessageBuilder::createChatRoomCustomMessage',
            {
          "sessionId": sessionId,
          "attachmentString": attachmentString,
        });

    if (__result__ == null) {
      return null;
    } else {
      final __return__ =
          com_netease_nimlib_sdk_chatroom_model_ChatRoomMessage.subInstance()
            ..refId = __result__
            ..tag__ = 'nim_fluttify';
      if (__return__ is Ref) kNativeObjectPool.add(__return__);
      return __return__;
    }
  }
}

extension com_netease_nimlib_sdk_msg_model_IMMessage_X
    on com_netease_nimlib_sdk_msg_model_IMMessage {
  Future<String> getCustomAttachment() async {
    // invoke native method
    final __result__ =
        await MethodChannel('com.fluttify/nim_fluttify').invokeMethod(
      'com.netease.nimlib.sdk.msg.model.IMMessage::getCustomAttachment',
      {"refId": refId},
    );

    return __result__;
  }

  Future<Message> toMessage() async {
    // 文字消息
    final messageType = await getMsgType();
    debugPrint('收到 $messageType 消息');
    switch (messageType) {
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.text:
        return TextMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.image:
        return ImageMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.audio:
        return AudioMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.video:
        return VideoMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.file:
        return FileMessage.android(this);
      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.custom:
        return CustomMessage.android(this);
      default:
        return null;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.location:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.avchat:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.notification:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.tip:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.robot:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.custom:
//        return CustomMessage.android(this);
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.appCustom:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.qiyuCustom:
//        // TODO: Handle this case.
//        break;
//      case com_netease_nimlib_sdk_msg_constant_MsgTypeEnum.undef:
//        // TODO: Handle this case.
//        break;
    }
  }
}

extension NIMMessageX on NIMMessage {
  Future<Message> toMessage() async {
    final messageType = await get_messageType();
    switch (messageType) {
      case NIMMessageType.NIMMessageTypeText:
        return TextMessage.ios(this);
      case NIMMessageType.NIMMessageTypeImage:
        return ImageMessage.ios(this);
      case NIMMessageType.NIMMessageTypeAudio:
        return AudioMessage.ios(this);
      case NIMMessageType.NIMMessageTypeVideo:
        return VideoMessage.ios(this);
      case NIMMessageType.NIMMessageTypeFile:
        return FileMessage.ios(this);
      case NIMMessageType.NIMMessageTypeCustom:
        return CustomMessage.ios(this);
      default:
        return null;
//    case NIMMessageType.NIMMessageTypeLocation:
//    // TODO: Handle this case.
//    break;
//    case NIMMessageType.NIMMessageTypeNotification:
//    // TODO: Handle this case.
//    break;
//    case NIMMessageType.NIMMessageTypeTip:
//    // TODO: Handle this case.
//    break;
//    case NIMMessageType.NIMMessageTypeRobot:
//    // TODO: Handle this case.
//    break;
    }
  }
}

extension NIMCustomObjectX on NIMCustomObject {
  Future<void> setAttachmentString(String attachmentString) async {
    return MethodChannel('com.fluttify/nim_fluttify').invokeMethod(
      'NIMCustomObject::setAttachmentString',
      {'attachmentString': attachmentString, 'refId': refId},
    );
  }

  Future<String> getAttachmentString() async {
    return MethodChannel('com.fluttify/nim_fluttify').invokeMethod(
      'NIMCustomObject::getAttachmentString',
      {'refId': refId},
    );
  }
}

extension SessionTypeX on SessionType {
  static SessionType fromAndroid(
      com_netease_nimlib_sdk_msg_constant_SessionTypeEnum androidModel) {
    switch (androidModel) {
      case com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.P2P:
        return SessionType.p2p;
      case com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.Team:
        return SessionType.team;
      case com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.ChatRoom:
        return SessionType.chatroom;
      default:
        return SessionType.p2p;
    }
  }

  static SessionType fromIOS(NIMSessionType iosModel) {
    switch (iosModel) {
      case NIMSessionType.NIMSessionTypeP2P:
        return SessionType.p2p;
      case NIMSessionType.NIMSessionTypeTeam:
        return SessionType.team;
      case NIMSessionType.NIMSessionTypeChatroom:
        return SessionType.chatroom;
      default:
        return SessionType.p2p;
    }
  }

  com_netease_nimlib_sdk_msg_constant_SessionTypeEnum androidModel() {
    com_netease_nimlib_sdk_msg_constant_SessionTypeEnum _type;
    switch (this) {
      case SessionType.p2p:
        _type = com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.P2P;
        break;
      case SessionType.team:
        _type = com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.Team;
        break;
      case SessionType.chatroom:
        _type = com_netease_nimlib_sdk_msg_constant_SessionTypeEnum.ChatRoom;
        break;
    }
    return _type;
  }

  NIMSessionType iosModel() {
    NIMSessionType _type;
    switch (this) {
      case SessionType.p2p:
        _type = NIMSessionType.NIMSessionTypeP2P;
        break;
      case SessionType.team:
        _type = NIMSessionType.NIMSessionTypeTeam;
        break;
      case SessionType.chatroom:
        _type = NIMSessionType.NIMSessionTypeChatroom;
        break;
    }
    return _type;
  }
}

extension com_netease_nimlib_sdk_StatusCode_X
    on com_netease_nimlib_sdk_StatusCode {
  StatusType toStatusType() {
    switch (this) {
      case com_netease_nimlib_sdk_StatusCode.CONNECTING:
        debugPrint('网易云信: 服务器连接中');
        return StatusType.connecting;
      case com_netease_nimlib_sdk_StatusCode.LOGINING:
        debugPrint('网易云信: 登录中');
        return StatusType.logining;
      case com_netease_nimlib_sdk_StatusCode.LOGINED:
        debugPrint('网易云信: 已经登录');
        return StatusType.logged;
      case com_netease_nimlib_sdk_StatusCode.UNLOGIN:
        debugPrint('网易云信: 登录失败');
        return StatusType.login_failed;
      case com_netease_nimlib_sdk_StatusCode.SYNCING:
        debugPrint('网易云信: 数据同步中');
        return StatusType.syncing;
      case com_netease_nimlib_sdk_StatusCode.NET_BROKEN:
        debugPrint('网易云信: 连接断开');
        return StatusType.net_broken;
      default:
        debugPrint('网易云信: 未登录');
        return StatusType.not_logged;
    }
  }
}

extension NIMLoginStepX on NIMLoginStep {
  StatusType toStatusType() {
    switch (this) {
      case NIMLoginStep.NIMLoginStepLogining:
        debugPrint('网易云信: 聊天室登录中');
        return StatusType.logining;
      case NIMLoginStep.NIMLoginStepLoginOK:
        debugPrint('网易云信: 聊天室已登录');
        return StatusType.logged;
      case NIMLoginStep.NIMLoginStepLoginFailed:
        debugPrint('网易云信: 登录失败');
        return StatusType.login_failed;
      case NIMLoginStep.NIMLoginStepLoseConnection:
        debugPrint('网易云信: 连接断开');
        return StatusType.net_broken;
      default:
        debugPrint('网易云信: 未知状态');
        return StatusType.logining;
    }
  }
}

extension NIMChatroomConnectionStateX on NIMChatroomConnectionState {
  StatusType toStatusType() {
    switch (this) {
      case NIMChatroomConnectionState.NIMChatroomConnectionStateEntering:
        debugPrint('网易云信: 聊天室登录中');
        return StatusType.logining;
      case NIMChatroomConnectionState.NIMChatroomConnectionStateEnterOK:
        debugPrint('网易云信: 聊天室已登录');
        return StatusType.logged;
      case NIMChatroomConnectionState.NIMChatroomConnectionStateEnterFailed:
        debugPrint('网易云信: 聊天室进入失败');
        return StatusType.not_logged;
      case NIMChatroomConnectionState.NIMChatroomConnectionStateLoseConnection:
        debugPrint('网易云信: 连接断开');
        return StatusType.net_broken;
      default:
        debugPrint('网易云信: 未知状态');
        return StatusType.logining;
    }
  }
}

extension com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason_X
    on com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason {
  KickOutReason toKickOutReason() {
    switch (this) {
      case com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason
          .CHAT_ROOM_INVALID:
        return KickOutReason.invalid_room;
      case com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason
          .KICK_OUT_BY_MANAGER:
        return KickOutReason.by_manager;
      case com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason
          .KICK_OUT_BY_CONFLICT_LOGIN:
        return KickOutReason.conflict_login;
      case com_netease_nimlib_sdk_chatroom_model_ChatRoomKickOutEvent_ChatRoomKickOutReason
          .BE_BLACKLISTED:
        return KickOutReason.black_list;
      default:
        return KickOutReason.unknown;
    }
  }
}

extension NIMChatroomKickReasonX on NIMChatroomKickReason {
  KickOutReason toKickOutReason() {
    switch (this) {
      case NIMChatroomKickReason.NIMChatroomKickReasonInvalidRoom:
        return KickOutReason.invalid_room;
      case NIMChatroomKickReason.NIMChatroomKickReasonByManager:
        return KickOutReason.by_manager;
      case NIMChatroomKickReason.NIMChatroomKickReasonByConflictLogin:
        return KickOutReason.conflict_login;
      // TODO 枚举序号不是递增, 会出错, 如果枚举有值, 就必须使用值
      case NIMChatroomKickReason.NIMChatroomKickReasonBlacklist:
        return KickOutReason.black_list;
      default:
        return KickOutReason.unknown;
    }
  }
}

extension com_netease_nimlib_sdk_NIMSDK_X on com_netease_nimlib_sdk_NIMSDK {
  static Future<com_netease_nimlib_sdk_msg_SystemMessageObserver>
      getSystemMessageObserver() async {
    // invoke native method
    final __result__ = await MethodChannel('com.fluttify/nim_fluttify')
        .invokeMethod(
            'com.netease.nimlib.sdk.NIMSDK::getSystemMessageObserver');

    // handle native call

    // convert native result to dart side object
    if (__result__ == null) {
      return null;
    } else {
      final __return__ =
          com_netease_nimlib_sdk_msg_SystemMessageObserver.subInstance()
            ..refId = __result__
            ..tag__ = 'nim_fluttify';
      if (__result__ is Ref) kNativeObjectPool.add(__return__);
      return __return__;
    }
  }
}

extension com_netease_nimlib_sdk_msg_MsgService_X
    on com_netease_nimlib_sdk_msg_MsgService {
  Future<List<com_netease_nimlib_sdk_msg_model_IMMessage>> queryMessageListExX(
      com_netease_nimlib_sdk_msg_model_IMMessage var1,
      com_netease_nimlib_sdk_msg_model_QueryDirectionEnum var2,
      int var3,
      bool var4) async {
    // invoke native method
    final __result__ = await MethodChannel('com.fluttify/nim_fluttify')
        .invokeMethod(
            'com.netease.nimlib.sdk.msg.MsgService::queryMessageListExX', {
      "var1": var1?.refId,
      "var2": var2.toValue(),
      "var3": var3,
      "var4": var4,
      "refId": refId,
    });

    // convert native result to dart side object
    if (__result__ == null) {
      return null;
    } else {
      return [
        for (final item in __result__)
          com_netease_nimlib_sdk_msg_model_IMMessage.subInstance()
            ..refId = item
            ..tag__ = 'nim_fluttify'
      ];
    }
  }
}
